/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __LFB_GDBUS_H__
#define __LFB_GDBUS_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.sigxcpu.Feedback */

#define LFB_GDBUS_TYPE_FEEDBACK (lfb_gdbus_feedback_get_type ())
#define LFB_GDBUS_FEEDBACK(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), LFB_GDBUS_TYPE_FEEDBACK, LfbGdbusFeedback))
#define LFB_GDBUS_IS_FEEDBACK(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), LFB_GDBUS_TYPE_FEEDBACK))
#define LFB_GDBUS_FEEDBACK_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), LFB_GDBUS_TYPE_FEEDBACK, LfbGdbusFeedbackIface))

struct _LfbGdbusFeedback;
typedef struct _LfbGdbusFeedback LfbGdbusFeedback;
typedef struct _LfbGdbusFeedbackIface LfbGdbusFeedbackIface;

struct _LfbGdbusFeedbackIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_end_feedback) (
    LfbGdbusFeedback *object,
    GDBusMethodInvocation *invocation,
    guint arg_id);

  gboolean (*handle_trigger_feedback) (
    LfbGdbusFeedback *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_app_id,
    const gchar *arg_event,
    GVariant *arg_hints,
    gint arg_timeout);

  const gchar * (*get_profile) (LfbGdbusFeedback *object);

  void (*feedback_ended) (
    LfbGdbusFeedback *object,
    guint arg_id,
    guint arg_reason);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LfbGdbusFeedback, g_object_unref)
#endif

GType lfb_gdbus_feedback_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *lfb_gdbus_feedback_interface_info (void);
guint lfb_gdbus_feedback_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void lfb_gdbus_feedback_complete_trigger_feedback (
    LfbGdbusFeedback *object,
    GDBusMethodInvocation *invocation,
    guint id);

void lfb_gdbus_feedback_complete_end_feedback (
    LfbGdbusFeedback *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void lfb_gdbus_feedback_emit_feedback_ended (
    LfbGdbusFeedback *object,
    guint arg_id,
    guint arg_reason);



/* D-Bus method calls: */
void lfb_gdbus_feedback_call_trigger_feedback (
    LfbGdbusFeedback *proxy,
    const gchar *arg_app_id,
    const gchar *arg_event,
    GVariant *arg_hints,
    gint arg_timeout,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean lfb_gdbus_feedback_call_trigger_feedback_finish (
    LfbGdbusFeedback *proxy,
    guint *out_id,
    GAsyncResult *res,
    GError **error);

gboolean lfb_gdbus_feedback_call_trigger_feedback_sync (
    LfbGdbusFeedback *proxy,
    const gchar *arg_app_id,
    const gchar *arg_event,
    GVariant *arg_hints,
    gint arg_timeout,
    guint *out_id,
    GCancellable *cancellable,
    GError **error);

void lfb_gdbus_feedback_call_end_feedback (
    LfbGdbusFeedback *proxy,
    guint arg_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean lfb_gdbus_feedback_call_end_feedback_finish (
    LfbGdbusFeedback *proxy,
    GAsyncResult *res,
    GError **error);

gboolean lfb_gdbus_feedback_call_end_feedback_sync (
    LfbGdbusFeedback *proxy,
    guint arg_id,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *lfb_gdbus_feedback_get_profile (LfbGdbusFeedback *object);
gchar *lfb_gdbus_feedback_dup_profile (LfbGdbusFeedback *object);
void lfb_gdbus_feedback_set_profile (LfbGdbusFeedback *object, const gchar *value);


/* ---- */

#define LFB_GDBUS_TYPE_FEEDBACK_PROXY (lfb_gdbus_feedback_proxy_get_type ())
#define LFB_GDBUS_FEEDBACK_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), LFB_GDBUS_TYPE_FEEDBACK_PROXY, LfbGdbusFeedbackProxy))
#define LFB_GDBUS_FEEDBACK_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), LFB_GDBUS_TYPE_FEEDBACK_PROXY, LfbGdbusFeedbackProxyClass))
#define LFB_GDBUS_FEEDBACK_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), LFB_GDBUS_TYPE_FEEDBACK_PROXY, LfbGdbusFeedbackProxyClass))
#define LFB_GDBUS_IS_FEEDBACK_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), LFB_GDBUS_TYPE_FEEDBACK_PROXY))
#define LFB_GDBUS_IS_FEEDBACK_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), LFB_GDBUS_TYPE_FEEDBACK_PROXY))

typedef struct _LfbGdbusFeedbackProxy LfbGdbusFeedbackProxy;
typedef struct _LfbGdbusFeedbackProxyClass LfbGdbusFeedbackProxyClass;
typedef struct _LfbGdbusFeedbackProxyPrivate LfbGdbusFeedbackProxyPrivate;

struct _LfbGdbusFeedbackProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  LfbGdbusFeedbackProxyPrivate *priv;
};

struct _LfbGdbusFeedbackProxyClass
{
  GDBusProxyClass parent_class;
};

GType lfb_gdbus_feedback_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LfbGdbusFeedbackProxy, g_object_unref)
#endif

void lfb_gdbus_feedback_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
LfbGdbusFeedback *lfb_gdbus_feedback_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
LfbGdbusFeedback *lfb_gdbus_feedback_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void lfb_gdbus_feedback_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
LfbGdbusFeedback *lfb_gdbus_feedback_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
LfbGdbusFeedback *lfb_gdbus_feedback_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define LFB_GDBUS_TYPE_FEEDBACK_SKELETON (lfb_gdbus_feedback_skeleton_get_type ())
#define LFB_GDBUS_FEEDBACK_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), LFB_GDBUS_TYPE_FEEDBACK_SKELETON, LfbGdbusFeedbackSkeleton))
#define LFB_GDBUS_FEEDBACK_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), LFB_GDBUS_TYPE_FEEDBACK_SKELETON, LfbGdbusFeedbackSkeletonClass))
#define LFB_GDBUS_FEEDBACK_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), LFB_GDBUS_TYPE_FEEDBACK_SKELETON, LfbGdbusFeedbackSkeletonClass))
#define LFB_GDBUS_IS_FEEDBACK_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), LFB_GDBUS_TYPE_FEEDBACK_SKELETON))
#define LFB_GDBUS_IS_FEEDBACK_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), LFB_GDBUS_TYPE_FEEDBACK_SKELETON))

typedef struct _LfbGdbusFeedbackSkeleton LfbGdbusFeedbackSkeleton;
typedef struct _LfbGdbusFeedbackSkeletonClass LfbGdbusFeedbackSkeletonClass;
typedef struct _LfbGdbusFeedbackSkeletonPrivate LfbGdbusFeedbackSkeletonPrivate;

struct _LfbGdbusFeedbackSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  LfbGdbusFeedbackSkeletonPrivate *priv;
};

struct _LfbGdbusFeedbackSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType lfb_gdbus_feedback_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LfbGdbusFeedbackSkeleton, g_object_unref)
#endif

LfbGdbusFeedback *lfb_gdbus_feedback_skeleton_new (void);


G_END_DECLS

#endif /* __LFB_GDBUS_H__ */
